<?php

namespace App\Http\Controllers\Api\V1;


use App\Models\AlbumAgentModel;
use App\Models\AlbumBannerModel;
use App\Models\AlbumCatModel;
use App\Models\AlbumCommentsModel;
use App\Models\AlbumFavoriteModel;
use App\Models\AlbumInformationModel;
use App\Models\AlbumManufacturerModel;
use App\Models\AlbumNavModel;
use App\Models\AlbumNewsModel;
use App\Models\AlbumProductModel;
use App\Models\AlbumProductPriceModel;
use App\Models\AlbumProductStyleModel;
use App\Models\AlbumUserModel;
use App\Models\AlbumXyxUserModel;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Validator, Response;
use App\Services\Base\ErrorCode;
use WXBizDataCrypt;
use EasyWeChat\Factory;

class AlbumController extends Controller
{

    private $wechat_app;


    public function albumSetting(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
        ], [
            'store_id.required' => '店铺信息未知',
        ]);
        if ($validator->fails()) {
            return $this->validatorError($validator->messages()->all(), ErrorCode::CLIENT_WRONG_PARAMS, '');
        }
        $store_id = $request->store_id;
        //小程序設置

        $setting = AlbumManufacturerModel::where('store_id',$store_id)->first();
        //轮播图
        $banner = AlbumBannerModel::where('store_id',$store_id)->orderByDesc('sort')->get();

        //底部导航栏
        $navbar = AlbumNavModel::where([['store_id',$store_id],['state',0]])->orderByDesc('sort')->get();

        //顶部菜单栏
        $menus = AlbumNavModel::where([['store_id',$store_id],['state',1]])->orderByDesc('sort')->get();

        $news = AlbumNewsModel::where([['store_id',$store_id]])->orderByDesc('sort')->paginate(5);

        return $this->api(compact('setting','banner','news','navbar','menus'));
    }

    /**
     * @api {post} /api/album/xcx_login 登陆(login)
     * @apiDescription 登陆(login)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {string}     code              小程序登录生成的code
     * @apiParam {string}     nickName          微信昵称
     * @apiParam {string}     avatar            微信头像
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": {
     *
     *      }
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function albumXcxLogin(Request $request)
    {

        $validator = Validator::make($request->all(),
            [
                'code' => 'required',
                'store_id' => 'required'
               /* 'nickName' => 'required',
                'avatar' => 'required',*/
            ],
            [
                'code.required' => 'code不能为空!',
                'store_id.required' => 'store_id不能为空!'
                /*'nickName.required' => 'nickName不能为空!',
                'avatar.required' => 'avatar不能为空!',*/
            ]
        );


        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }

        $storeid = $request->get('store_id');

        $this->wechat_app = AlbumManufacturerModel::where('store_id',$storeid)->first();
        $config = [
            'app_id' => $this->wechat_app->app_id,
            'secret' => $this->wechat_app->app_secret,

            // 下面为可选项
            // 指定 API 调用返回结果的类型：array(default)/collection/object/raw/自定义类名
            'response_type' => 'array',
        ];
        $app = Factory::miniProgram($config);


        $code = $request->get('code');
        $session = $app->auth->session($code);
        \Log::info(json_encode($session));
        $openid = $session['openid'];


        $userinfo = AlbumUserModel::where('wechat_open_id', $openid)->where('store_id',$storeid)->first(['id', 'username','wechat_open_id','avatar']);

        if ($userinfo) {
            return $this->api(compact('userinfo'));
        } else {
            $data['wechat_open_id'] = $openid;
            $data['username'] = $request->get('nickName');
            $data['avatar'] = $request->get('avatar');
            $data['is_dealer'] = 0;

            $userinfo = AlbumUserModel::create($data);

            return $this->api($userinfo);
        }
    }

    /**
     * @api {post} /api/album/xyx_login 登陆(xyx_login)
     * @apiDescription 登陆(xyx_login)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [code]
     * @apiParam {int}    [encrypted_data]  加密数据
     * @apiParam {int}    [iv]  偏移量
     * @apiParam {int}    [store_id]  商户id
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": [
     *
     *      ]
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function albumXyxLogin(Request $request)
    {
        $datas = $request->input();
        //dd($datas);
       // print_r($datas);die;
        $this->wechat_app = AlbumManufacturerModel::where('store_id',$datas['store_id'])->first();
        $config = [
            'app_id' => $this->wechat_app->xyx_id,
            'secret' => $this->wechat_app->xyx_secret,

            // 下面为可选项
            // 指定 API 调用返回结果的类型：array(default)/collection/object/raw/自定义类名
            'response_type' => 'array',


        ];
        $validator = Validator::make($request->all(),
            [
                'code' => 'required',
            ],[
                'code.required' => 'code不能为空!'
            ]
        );
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $app = Factory::miniProgram($config);
        $res = $app->auth->session($datas['code']);

        if (!$res || empty($res['openid'])) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '获取用户OpenId失败!', $validator->messages());
        }

        $session_key = $res['session_key'];


            $check = AlbumXyxUserModel::where('wechat_open_id',$res['openid'])->first();
            if(!$check){
                $add['username'] = preg_replace('/[\xf0-\xf7].{3}/', '', $datas['nickName']);
                $add['wechat_open_id'] = $res['openid'];
                $add['wechat_union_id'] = '';
                $add['avatar'] = $datas['avatar'];
                $add['is_agent'] = 0;
                $add['store_id'] = $datas['store_id'];
                $res = AlbumXyxUserModel::create($add);
                if($res){
                    $data_user = AlbumXyxUserModel::where('wechat_open_id',$res['openid'])->first();
                    $user = [

                        'user_id'=>$data_user['id'],
                        'avatar'=>$data_user['avatar'],
                        'username'=>$data_user['username'],
                        'is_agent'=>0,
                        'agent_id'=>'',

                    ];
                }else{
                    $user=[
                        'error'=>1
                    ];
                }
            } else {
                //print_r($check);die;
                $save['username'] = preg_replace('/[\xf0-\xf7].{3}/', '', $datas['nickName']);
                $save['avatar'] = $datas['avatar'];
                $res = AlbumXyxUserModel::where('wechat_open_id',$res['openid'])->update($save);
                //echo 111;
                    //print_r($check);die;
                    if($check->is_agent == 1){
                        $user_agent = AlbumAgentModel::where('user_id',$check->id)->first();
                        $agent_id = $user_agent['id'];
                    } else {
                        $agent_id = '';
                    }
                    $user = [

                        'user_id'=>$check->id,
                        'avatar'=>$datas['avatar'],
                        'username'=>$datas['nickName'],
                        'is_agent'=>$check->is_agent,
                        'agent_id'=>$agent_id,

                    ];

            }

        return $this->api($user);
    }


    /*
    * curl get请求
    */
    public function curl_get($url)
    {
        //初始化
        $ch = curl_init();
        //设置选项，包括URL
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_HEADER, 0);
        $output = curl_exec($ch);
        curl_close($ch);

        return $output;
    }

    private function getOpenid($code)
    {
        $api = "https://api.weixin.qq.com/sns/jscode2session?appid={$this->wechat_app->app_id}&secret={$this->wechat_app->app_secret}&js_code={$code}&grant_type=authorization_code";
        $res = $this->curl_get($api);
        $res = json_decode($res, true);
        return $res;
    }

    private function getOpenidxyx($code)
    {
        //$api = "https://api.weixin.qq.com/sns/jscode2session?appid={$this->wechat_app->xyx_id}&secret={$this->wechat_app->xyx_secret}&js_code={$code}&grant_type=authorization_code";
        $api = "https://api.weixin.qq.com/sns/jscode2session?appid={$this->wechat_app->xyx_id}&secret={$this->wechat_app->xyx_secret}&js_code={$code}&grant_type=authorization_code";
        $res = $this->curl_get($api);
        $res = json_decode($res, true);
        return $res;
    }
    /**
     * @api {get} api/album/goods 商品列表(goods)
     * @apiDescription 商品列表(goods)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [cat_id]  分类id
     * @apiParam {string}    [keywords]  关键词.
     * @apiParam {int}    [status]  状态  1 只选择热销 2 只选择最新上市 3只选择一个风格 4 同时选择热销和最新上市 5同时选择热销和风格 6同时选择最新上市和风格 7全选 0全不选
     * @apiParam {int}    [style]  风格
     * @apiParam {int}    [store_id]  商户id
     * @apiParam {int}    [agent_id]  经销商id
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": {
     *         "goods": []//分类商品
     *         "name": 品牌名
     *     }
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function albumGoods(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'cat_id' => 'required',
            'store_id' => 'required',
            'status' => 'required',
        ],[
            'cat_id.required'=>'缺少分类参数',
            'store_id.required'=>'缺少商户参数',
            'status.required'=>'缺少状态参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $data = $request->input();
        //dd($data);
        $cat_id = request('cat_id');
        $store_id = request('store_id');
        $status = request('status');
        $style = request('style');
        if(isset($data['keywords'])&&!empty($data['keywords'])) {
            $keywords = '%'.$data['keywords'].'%';
            $goods = AlbumProductModel::where([['name','like',$keywords],['store_id',$data['store_id']]]);
        } else {
            $goods = AlbumProductModel::where([['cat_id',$cat_id],['store_id',$store_id]]);
        }
        if($status == 1) {
            $goods->where([['hot_cake', 1]]);
        }
        if($status == 2){
            $goods->where('news',1);
        }
        if($status == 3){
            $goods->where('style',$style);
        }


        $goods = $goods->select('id','cover_pic','name','style','hot_cake','news')->orderByDesc('sort')->get();

        foreach($goods as $key =>$val){
            if(isset($data['agent_id'])){
               // dd(111);
                $check = AlbumProductPriceModel::where([['agent_id',$data['agent_id']],['store_id',$data['store_id']],['product_id',$val['id']]])->first();
                if($check){
                    $goods[$key]['price'] = $check->price;
                }else{
                    $goods[$key]['price'] = '';
                }
            }else{
                $goods[$key]['price'] = '';
            }
        }
        $data =AlbumManufacturerModel::where('store_id',$store_id)->first();
        $name = $data['name'];
        return $this->api(compact('goods','name'));
    }



    /**
     * @api {get} /api/album/goods-detail 商品详细(goods-detail)
     * @apiDescription 商品列表(goods-detail)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [goods_id]  商品id
     * @apiParam {int}    [agent_id]  经销商id 模拟值为10
     * @apiParam {int}    [store_id]  商户id 模拟值为0
     * @apiParam {int}    [user_id]  用户id
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": []//商品详细 * 新增返回值 address 经销商地址信息 is_favorite 是否已收藏 0 否 1 是
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function albumGoodsDetail(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'goods_id' => 'required',
            'user_id' => 'required',
        ],[
            'goods_id.required'=>'缺少商品参数',
            'user_id.required'=>'缺少用户参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $goods_id = request('goods_id');
        $agent_id = request('agent_id');
        $store_id = request('store_id');
        $user_id = request('user_id');
        $goods = AlbumProductModel::where([['id',$goods_id],['store_id',$store_id]])->first();
        if(!empty($goods) && $agent_id != ''){
            $price = DB::table('album_product_price')->where([['agent_id',$agent_id],['store_id',$store_id],['product_id',$goods['id']]])->first();
            if(!empty($price)){
                $goods->price = $price->price;
                $goods->mobile = $price->mobile;
                $address = AlbumAgentModel::where('id',$agent_id)->first();
                $goods->address = $address;
            }else{
                $goods->price = '';
                $goods->mobile = '';
                $goods->address = '';
            }
            $check_favorite = AlbumFavoriteModel::where([['user_id',$user_id],['store_id',$store_id],['product_id',$goods['id']]])->first();
            if($check_favorite){
                $goods['is_favorite'] = 1;
                $goods['favorite_id'] = $check_favorite->id;
            }else{
                $goods['is_favorite'] = 0;
                $goods['favorite_id'] = '';
            }
        }

        return $this->api($goods);
    }

    /**
     * @api {get} /api/album/favorite_list 收藏列表(favorite_list)
     * @apiDescription 收藏列表(favorite_list)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [store_id]  商户id 模拟值为0
     * @apiParam {int}    [user_id]  用户id
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": {
     *
     *     }
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */

    public function albumFavoriteList(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
            'user_id' => 'required',
        ],[
            'user_id.required'=>'缺少用户参数',
            'store_id.required'=>'缺少商户参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $data = $request->input();
        $favorite = AlbumFavoriteModel::where([['user_id',$data['user_id']],['store_id',$data['store_id']]])->get();
        foreach ($favorite as $key=>$val) {
            $favorite[$key]['goods'] = AlbumProductModel::where([['id',$val['product_id']],['store_id',$data['store_id']]])->first();
        }
        return $this->api($favorite);
    }

    /**
     * @api {get} /api/album/checklogin 登陆应用(checklogin)
     * @apiDescription 登陆应用(checklogin)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [store_id]  商户id 模拟值为0
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": {
     *
     *     }
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */

    public function albumchecklogin(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
        ],[
            'store_id.required'=>'缺少商户参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $data = $request->input();
        $favorite = AlbumManufacturerModel::where([['store_id',$data['store_id']]])->first();

        $conf = $favorite->redirectapp;
        return $this->api($conf);
    }

    /**
     * @api {get} /api/album/favorite_del 收藏删除(favorite_del)
     * @apiDescription 收藏删除(favorite_del)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [store_id]  商户id 模拟值为0
     * @apiParam {int}    [user_id]  用户id
     * @apiParam {int}    [favorite_id]  收藏id
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data":[]//返回状态
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */

    public function albumFavoriteDel(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
            'user_id' => 'required',
            'favorite_id' => 'required',
        ],[
            'user_id.required'=>'缺少用户参数',
            'store_id.required'=>'缺少商户参数',
            'favorite_id.required'=>'缺少收藏参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $data = $request->input();
        $favorite = AlbumFavoriteModel::find($data['favorite_id']);
        if(!$favorite){
            $d = [
                'code' =>1,
                'msg' =>'删除失败，或者该收藏已移除',
            ];
        } else {
            $res = $favorite->delete();
            if($res){
                $d = [
                    'code' =>1,
                    'msg' =>'删除成功',
                ];
            } else {
                $d = [
                    'code' =>1,
                    'msg' =>'删除失败，或者该收藏已移除',
                ];
            }
        }
        return $this->api($d);
    }

    /**
     * @api {get} /api/album/add_favorite 添加收藏(add_favorite)
     * @apiDescription 添加收藏(favorite_list)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [store_id]  商户id
     * @apiParam {int}    [user_id]  用户id
     * @apiParam {int}    [product_id]  商品id
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": []//返回信息
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */

    public function albumAddFavorite(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
            'user_id' => 'required',
            'product_id' => 'required',
        ],[
            'user_id.required'=>'缺少用户参数',
            'store_id.required'=>'缺少商户参数',
            'product_id.required'=>'缺少商品参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $data = $request->input();
        $check_user = AlbumXyxUserModel::find($data['user_id']);
        if(!$check_user){
            $d = [
                'code' =>1,
                'msg' =>'该用户不存在',
            ];
            return $this->api($d);
        }
        $res = AlbumFavoriteModel::create($data);
        if($res){
            $d = [
                'code' =>0,
                'msg' =>'success',
            ];
        }else{
            $d = [
                'code' =>1,
                'msg' =>'error',
            ];
        }
        return $this->api($d);
    }
    /**
     * @api {get} /api/album/cat 分类列表(cat)
     * @apiDescription 画册分类(cat)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [parent_id]  一级菜单传0 二级菜单的id从一级菜单里面获取
     * @apiParam {int}    [store_id]  商户id 模拟值为0
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": []//分类
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function albumCat(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
        ],[
            'store_id.required'=>'缺少商户参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $cat_id = 0;
        $store_id = request('store_id');
        $cats = AlbumCatModel::where([['parent_id',$cat_id],['store_id',$store_id]])->orderByDesc('sort')->get();
        return $this->api($cats);
    }

    /**
     * @api {get} /api/album/style 属性列表(style)
     * @apiDescription 分类样式(style)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [store_id]  商户id 模拟值为0
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": []//属性
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function albumStyle(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
        ],[
            'store_id.required'=>'缺少商户参数',
        ]);
        if ($validator->fails()) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '传入参数不正确!', $validator->messages());
        }
        $store_id = request('store_id');
        $style = AlbumProductStyleModel::where([['store_id',$store_id]])->orderByDesc('id')->get();
        return $this->api($style);
    }

    /**
     * @api {get} /api/album/set-price 经销商修改价格(set-price)
     * @apiDescription 画册(set-price)
     * @apiGroup Album
     * @apiPermission none
     * @apiVersion 0.1.0
     * @apiParam {int}    [goods_id]  商品id
     * @apiParam {int}    [agent_id]  经销商id 模拟值为10
     * @apiParam {int}    [store_id]  商户id 模拟值为0
     * @apiParam {int}    [type]  修改类型 0 电话 1 价格
     * @apiParam {string}    [mobile]  电话号码
     * @apiParam {string}    [address]  地址
     * @apiParam {double}    [price]  价格
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data":[
     *          "msg":返回信息,
     *          "data":修改后价格
     *      ]
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function albumSetPrice(Request $request)
    {
        $data = $request->all();
        //print_r($data);
        $save = array();
        $return_data = array();
        if($data['type'] == 0) {
            $save['mobile'] = $data['mobile'];
            $product = AlbumProductModel::where('store_id',$data['store_id'])->get();
            foreach($product as $key=>$val){
                $check = AlbumProductPriceModel::where([['agent_id',$data['agent_id']],['store_id',$data['store_id']],['product_id',$val['id']]])->first();
                if(empty($check)){
                    $save['agent_id'] = $data['agent_id'];
                    $save['store_id'] = $data['store_id'];
                    $save['product_id'] = $val['id'];
                    $res = AlbumProductPriceModel::create($save);
                }else{
                    $res = AlbumProductPriceModel::where([['agent_id',$data['agent_id']],['store_id',$data['store_id']],['product_id',$val['id']]])->update($save);
                }
                if(!$res){
                    $return['msg'] = 'error';
                    return $this->api($return);
                }
            }
            $update_agent['phone'] = $data['mobile'];
            $update_agent['address'] = $data['address'];

            $update_res = AlbumAgentModel::where('id',$data['agent_id'])->update($update_agent);
            if(!$update_res){
                $return['msg'] = 'error';
                return $this->api($return);
            }
            $return_data['mobile'] = $data['mobile'];
            $return_data['address'] = $data['address'];
            $return['msg'] = 'success';
        } elseif ($data['type'] == 1){
            $save['price'] = $data['price'];
            $check = AlbumProductPriceModel::where([['agent_id',$data['agent_id']],['store_id',$data['store_id']],['product_id',$data['goods_id']]])->first();
            if(empty($check)){
                $save['agent_id'] = $data['agent_id'];
                $save['store_id'] = $data['store_id'];
                $save['product_id'] = $data['goods_id'];
                $res = AlbumProductPriceModel::create($save);
            }else{
                $res = AlbumProductPriceModel::where([['agent_id',$data['agent_id']],['store_id',$data['store_id']],['product_id',$data['goods_id']]])->update($save);
            }
            if($res){
                $return['msg'] = 'success';
                $return_data['price'] = $data['price'];
            } else {
                $return['msg'] = 'error';
            }
        }
        $return['data'] = $return_data;
        return $this->api($return);
    }







}
